@@ -3,9 +3,8 @@ package HTTP::Server::Simple::CGI::Environment;
 
 use strict;
 use warnings;
-use HTTP::Server::Simple;
 
-use vars qw(%ENV_MAPPING);
+our $VERSION = $HTTP::Server::Simple::VERSION;
 
 my %clean_env = %ENV;
 
@@ -15,9 +14,9 @@ HTTP::Server::Simple::CGI::Environment - a HTTP::Server::Simple mixin to provide
 
 =head1 DESCRIPTION
 
-This mixin abstracts the CGI protocol out from
-L<HTTP::Server::Simple::CGI> so that it's easier to provide your own
-CGI handlers with L<HTTP::Server::Simple> which B<don't> use CGI.pm
+This mixin abstracts the CGI protocol out from HTTP::Server::Simple::CGI so that 
+it's easier to provide your own CGI handlers with HTTP::Server::Simple which 
+B<don't> use CGI.pm
 
 =head2 setup_environment
 
@@ -31,20 +30,20 @@ start-up state.
 sub setup_environment {
     %ENV = (
         %clean_env,
-        SERVER_SOFTWARE   => "HTTP::Server::Simple/$HTTP::Server::Simple::VERSION",
+        SERVER_SOFTWARE   => "HTTP::Server::Simple/$VERSION",
         GATEWAY_INTERFACE => 'CGI/1.1'
     );
 }
 
 =head2 setup_server_url
 
-Sets up the C<SERVER_URL> environment variable
+Sets up the SERVER_URL environment variable
 
 =cut
 
 sub setup_server_url {
     $ENV{SERVER_URL}
-        ||= ( "http://" . ($ENV{SERVER_NAME} || 'localhost') . ":" . ( $ENV{SERVER_PORT}||80) . "/" );
+        ||= ( "http://" . $ENV{SERVER_NAME} . ":" . $ENV{SERVER_PORT} . "/" );
 }
 
 =head2 setup_environment_from_metadata
@@ -56,7 +55,7 @@ See the docs in L<HTTP::Server::Simple> for more detail.
 
 =cut
 
-%ENV_MAPPING = (
+our %ENV_MAPPING = (
     protocol     => "SERVER_PROTOCOL",
     localport    => "SERVER_PORT",
     localname    => "SERVER_NAME",
@@ -65,7 +64,6 @@ See the docs in L<HTTP::Server::Simple> for more detail.
     method       => "REQUEST_METHOD",
     peeraddr     => "REMOTE_ADDR",
     peername     => "REMOTE_HOST",
-    peerport     => "REMOTE_PORT",
     query_string => "QUERY_STRING",
 );
 
@@ -82,9 +80,6 @@ sub setup_environment_from_metadata {
         }
     }
 
-    # Apache and lighttpd both do one layer of unescaping on
-    # path_info; we should duplicate that.
-    $ENV{PATH_INFO} =~ s/%([0-9A-Fa-f]{2})/chr(hex($1))/eg;
 }
 
 =head2  header
@@ -102,10 +97,10 @@ sub header {
     $tag =~ s/^COOKIES$/COOKIE/;
     $tag =~ s/-/_/g;
     $tag = "HTTP_" . $tag
-        unless $tag =~ m/^CONTENT_(?:LENGTH|TYPE)$/;
+        unless $tag =~ m/^(?:CONTENT_(?:LENGTH|TYPE)|COOKIE)$/;
 
     if ( exists $ENV{$tag} ) {
-        $ENV{$tag} .= ", $value";
+        $ENV{$tag} .= "; $value";
     }
     else {
         $ENV{$tag} = $value;
